# Comenzar Aqui

Para empezar con una descripcion muy general del uso de `pydap` como herramienta de acceso, navegue al [tutorial de 5 minutos](5_minute_tutorial). O puede navegar a uno de los siguientes ejemplos

::::{grid} 1 1 1 3
:class-container: text-center
:gutter: 3

:::{grid-item-card}
:link: notebooks/ECCO
:link-type: doc
:class-header: bg-light

ECCOv4 via EarthData
^^^

```{image} https://github.com/OPENDAP/ESIP2024/blob/main/binder/img/ECCO_native.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: notebooks/PACE
:link-type: doc
:class-header: bg-light

PACE via EarthData
^^^

```{image} https://github.com/OPENDAP/ESIP2024/blob/main/binder/img/pace_subset.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: notebooks/CMIP6
:link-type: doc
:class-header: bg-light

CMIP6 via ESGF
^^^

```{image} https://github.com/OPENDAP/ESIP2024/blob/main/binder/img/Surface_Temperature.png?raw=true
:height: 200
```
:::


::::
